@@ -66,10 +66,14 @@
 (defconst jira-regexp-emoji
   (rx symbol-start ":" (submatch (+ (or lower digit "-"))) ":" symbol-end))
 
+(defconst jira-regexp-task-item
+  (rx bol (* space) (submatch "[" (? any) "]") (submatch (*? not-newline)) eol))
+
 (defvar jira-inline-block-keywords
   `((,jira-regexp-mention . 'jira-face-mention)
     (,jira-regexp-code . 'jira-face-code)
     (,jira-regexp-link . 'jira-face-link)
+    (,jira-regexp-task-item 1 font-lock-builtin-face)
     (,jira-regexp-emoji 0 'jira-face-emoji-reference prepend)))
 
 (defconst jira-regexp-blockquote
@@ -195,6 +199,10 @@
 ;; ||heading 1||heading 2||heading 3||
 ;; |col A1|col A2|col A3|
 ;; |col B1|col B2|col B3|
+
+;; Action items:
+;; [] incomplete task
+;; [x] completed task
 "
   "Instructions included in `jira-edit-mode' buffers.")
 
